@@ -1,9 +1,9 @@
-/* $Id: files.c 4448 2009-11-29 06:13:22Z astyanax $ */
+/* $Id: files.c 4460 2009-12-09 16:51:43Z astyanax $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
@@ -146,7 +146,7 @@ void open_buffer(const char *filename, bool undoable)
     /* If we have a non-new file, read it in.  Then, if the buffer has
      * no stat, update the stat, if applicable. */
     if (rc > 0) {
-	read_file(f, rc, filename, undoable);
+	read_file(f, rc, filename, undoable, new_buffer);
 #ifndef NANO_TINY
 	if (openfile->current_stat == NULL) {
 	    openfile->current_stat =
@@ -196,7 +196,7 @@ void replace_buffer(const char *filename)
 
     /* If we have a non-new file, read it in. */
     if (rc > 0)
-	read_file(f, rc, filename, FALSE);
+	read_file(f, rc, filename, FALSE, TRUE);
 
     /* Move back to the beginning of the first line of the buffer. */
     openfile->current = openfile->fileage;
@@ -390,9 +390,9 @@ filestruct *read_line(char *buf, filestruct *prevnode, bool
 /* Read an open file into the current buffer.  f should be set to the
  * open file, and filename should be set to the name of the file.
  * undoable  means do we want to create undo records to try and undo this.
- * Will also attempt to check file writability if fd > 0
+ * Will also attempt to check file writability if fd > 0 and checkwritable == TRUE
  */
-void read_file(FILE *f, int fd, const char *filename, bool undoable)
+void read_file(FILE *f, int fd, const char *filename, bool undoable, bool checkwritable)
 {
     size_t num_lines = 0;
 	/* The number of lines in the file. */
@@ -514,7 +514,7 @@ void read_file(FILE *f, int fd, const char *filename, bool undoable)
     if (ferror(f))
 	nperror(filename);
     fclose(f);
-    if (fd > 0) {
+    if (fd > 0 && checkwritable) {
 	close(fd);
 	writable = is_file_writable(filename);
     }
@@ -1092,7 +1092,6 @@ char *get_full_path(const char *origpath)
     char *d_here, *d_there, *d_there_file = NULL;
     const char *last_slash;
     bool path_only;
-    int shutup;
 
     if (origpath == NULL)
     	return NULL;
@@ -1191,7 +1190,7 @@ char *get_full_path(const char *origpath)
 	    /* Finally, go back to the path specified in d_here,
 	     * where we were before.  We don't check for a chdir()
 	     * error, since we can do nothing if we get one. */
-	    shutup = chdir(d_here);
+	    IGNORE_CALL_RESULT(chdir(d_here));
 
 	    /* Free d_here, since we're done using it. */
 	    free(d_here);
