@@ -1,9 +1,9 @@
-/* $Id: global.c 4449 2009-11-29 06:24:10Z astyanax $ */
+/* $Id: global.c 4461 2009-12-09 17:09:37Z astyanax $ */
 /**************************************************************************
  *   global.c                                                             *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
@@ -655,8 +655,9 @@ void shortcut_init(bool unjustify)
         free(f);
     }
 
-    add_to_funcs(DO_HELP_VOID, MALL, get_help_msg, IFSCHELP(nano_help_msg),
-	FALSE, VIEW);
+    add_to_funcs(DO_HELP_VOID,
+	(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE|MWRITEFILE|MINSERTFILE|MEXTCMD|MSPELL|MBROWSER|MWHEREISFILE|MGOTODIR),
+	get_help_msg, IFSCHELP(nano_help_msg), FALSE, VIEW);
 
     add_to_funcs( CANCEL_MSG,
 	(MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE|MWRITEFILE|MINSERTFILE|MEXTCMD|MSPELL|MWHEREISFILE|MGOTODIR|MYESNO),
@@ -669,8 +670,6 @@ void shortcut_init(bool unjustify)
 #endif
 	exit_msg, IFSCHELP(nano_exit_msg), FALSE, VIEW);
 
-    add_to_funcs(DO_EXIT, MHELP, exit_msg, IFSCHELP(nano_exit_msg), FALSE, VIEW);
-
 #ifndef DISABLE_BROWSER
     add_to_funcs(DO_EXIT, MBROWSER, exit_msg, IFSCHELP(nano_exitbrowser_msg), FALSE, VIEW);
 #endif
@@ -702,9 +701,9 @@ void shortcut_init(bool unjustify)
     add_to_funcs(DO_SEARCH, MMAIN|MBROWSER, whereis_msg,
 	IFSCHELP(nano_whereis_msg), FALSE, VIEW);
 
-    add_to_funcs(DO_PAGE_UP, MMAIN|MHELP,
+    add_to_funcs(DO_PAGE_UP, MMAIN|MHELP|MBROWSER,
 	prev_page_msg, IFSCHELP(nano_prevpage_msg), FALSE, VIEW);
-    add_to_funcs(DO_PAGE_DOWN, MMAIN|MHELP,
+    add_to_funcs(DO_PAGE_DOWN, MMAIN|MHELP|MBROWSER,
 	next_page_msg, IFSCHELP(nano_nextpage_msg), TRUE, VIEW);
 
 
@@ -739,11 +738,11 @@ void shortcut_init(bool unjustify)
 #endif
 
     add_to_funcs(DO_FIRST_LINE,
-	(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE|MHELP),
+	(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE),
 	first_line_msg, IFSCHELP(nano_firstline_msg), FALSE, VIEW);
 
     add_to_funcs(DO_LAST_LINE,
-	(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE|MHELP),
+	(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE),
 	last_line_msg, IFSCHELP(nano_lastline_msg), TRUE, VIEW);
 
 
@@ -793,12 +792,6 @@ void shortcut_init(bool unjustify)
 
 #endif
 
-    add_to_funcs(DO_PAGE_UP, MBROWSER,
-	prev_page_msg, IFSCHELP(nano_prevpage_msg), FALSE, VIEW);
-    add_to_funcs(DO_PAGE_DOWN, MBROWSER,
-	next_page_msg, IFSCHELP(nano_nextpage_msg), TRUE, VIEW);
-
-
     add_to_funcs(DO_RIGHT, (MMAIN|MBROWSER), N_("Forward"), IFSCHELP(nano_forward_msg),
 	FALSE, VIEW);
     add_to_funcs(DO_RIGHT, MALL, "", "", FALSE, VIEW);
@@ -1001,6 +994,10 @@ void shortcut_init(bool unjustify)
 #ifndef DISABLE_HELP
     add_to_funcs( REFRESH_MSG, MHELP,
 	refresh_msg, nano_refresh_msg, FALSE, VIEW);
+
+    add_to_funcs(DO_EXIT, MHELP, exit_msg, IFSCHELP(nano_exit_msg), FALSE, VIEW);
+
+
 #endif
 
 #ifndef DISABLE_BROWSER
@@ -1019,12 +1016,15 @@ void shortcut_init(bool unjustify)
 
     currmenu = MMAIN;
 
-    add_to_sclist(MALL, "^G", DO_HELP_VOID, 0, TRUE);
-    add_to_sclist(MALL, "F1", DO_HELP_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE|MWRITEFILE|MINSERTFILE|MEXTCMD|MSPELL|MBROWSER|MWHEREISFILE|MGOTODIR,
+	"^G", DO_HELP_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MWHEREIS|MREPLACE|MREPLACE2|MGOTOLINE|MWRITEFILE|MINSERTFILE|MEXTCMD|MSPELL|MBROWSER|MWHEREISFILE|MGOTODIR,
+	"F1", DO_HELP_VOID, 0, TRUE);
     add_to_sclist(MMAIN|MHELP|MBROWSER, "^X", DO_EXIT, 0, TRUE);
     add_to_sclist(MMAIN|MHELP|MBROWSER, "F2", DO_EXIT, 0, TRUE);
     add_to_sclist(MMAIN, "^_", DO_GOTOLINECOLUMN_VOID, 0, TRUE);
     add_to_sclist(MMAIN, "F13", DO_GOTOLINECOLUMN_VOID, 0, TRUE);
+    add_to_sclist(MMAIN, "M-G", DO_GOTOLINECOLUMN_VOID, 0, TRUE);
     add_to_sclist(MMAIN, "^O", DO_WRITEOUT_VOID, 0, TRUE);
     add_to_sclist(MMAIN, "F3", DO_WRITEOUT_VOID, 0, TRUE);
 #ifndef DISABLE_JUSTIFY
@@ -1052,9 +1052,6 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MMAIN, "^T", DO_SPELL, 0, TRUE);
     add_to_sclist(MMAIN, "F12", DO_SPELL, 0, TRUE);
 #endif
-    add_to_sclist(MMAIN, "^_", DO_GOTOLINECOLUMN_VOID, 0, TRUE);
-    add_to_sclist(MMAIN, "F13", DO_GOTOLINECOLUMN_VOID, 0, TRUE);
-    add_to_sclist(MMAIN, "M-G", DO_GOTOLINECOLUMN_VOID, 0, TRUE);
     add_to_sclist(MMAIN, "^\\", DO_REPLACE, 0, TRUE);
     add_to_sclist(MMAIN, "F14", DO_REPLACE, 0, TRUE);
     add_to_sclist(MMAIN, "M-R", DO_REPLACE, 0, TRUE);
@@ -1065,8 +1062,8 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MMAIN, "^^", DO_MARK, 0, TRUE);
     add_to_sclist(MMAIN, "F15", DO_MARK, 0, TRUE);
     add_to_sclist(MMAIN, "M-A", DO_MARK, 0, TRUE);
-    add_to_sclist(MALL, "M-W", DO_RESEARCH, 0, TRUE);
-    add_to_sclist(MALL, "F16", DO_RESEARCH, 0, TRUE);
+    add_to_sclist(MMAIN|MBROWSER, "M-W", DO_RESEARCH, 0, TRUE);
+    add_to_sclist(MMAIN|MBROWSER, "F16", DO_RESEARCH, 0, TRUE);
     add_to_sclist(MMAIN, "M-^", DO_COPY_TEXT, 0, TRUE);
     add_to_sclist(MMAIN, "M-6", DO_COPY_TEXT, 0, TRUE);
     add_to_sclist(MMAIN, "M-}", DO_INDENT_VOID, 0, TRUE);
@@ -1084,10 +1081,10 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MALL, "kleft", DO_LEFT, 0, TRUE);
     add_to_sclist(MMAIN, "^Q", XON_COMPLAINT, 0, TRUE);
     add_to_sclist(MMAIN, "^S", XOFF_COMPLAINT, 0, TRUE);
-    add_to_sclist(MMAIN|MBROWSER, "^P", DO_UP_VOID, 0, TRUE);
-    add_to_sclist(MMAIN|MBROWSER, "kup", DO_UP_VOID, 0, TRUE);
-    add_to_sclist(MMAIN|MBROWSER, "^N", DO_DOWN_VOID, 0, TRUE);
-    add_to_sclist(MMAIN|MBROWSER, "kdown", DO_DOWN_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MHELP|MBROWSER, "^P", DO_UP_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MHELP|MBROWSER, "kup", DO_UP_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MHELP|MBROWSER, "^N", DO_DOWN_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MHELP|MBROWSER, "kdown", DO_DOWN_VOID, 0, TRUE);
     add_to_sclist(MALL, "^A", DO_HOME, 0, TRUE);
     add_to_sclist(MALL, "khome", DO_HOME, 0, TRUE);
     add_to_sclist(MALL, "^E", DO_END, 0, TRUE);
@@ -1132,6 +1129,9 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MBROWSER|MWHEREISFILE, "M-|",  FIRST_FILE_MSG, 0, TRUE);
     add_to_sclist(MBROWSER|MWHEREISFILE, "M-/",  LAST_FILE_MSG, 0, TRUE);
     add_to_sclist(MBROWSER|MWHEREISFILE, "M-?",  LAST_FILE_MSG, 0, TRUE);
+    add_to_sclist(MBROWSER|MWHEREISFILE, "^_",  GOTO_DIR_MSG, 0, TRUE);
+    add_to_sclist(MBROWSER|MWHEREISFILE, "F13",  GOTO_DIR_MSG, 0, TRUE);
+    add_to_sclist(MBROWSER|MWHEREISFILE, "M-G",  GOTO_DIR_MSG, 0, TRUE);
 #ifndef NANO_TINY
     add_to_sclist(MMAIN, "M-]", DO_FIND_BRACKET, 0, TRUE);
     add_to_sclist(MMAIN, "M--", DO_SCROLL_UP, 0, TRUE);
