@@ -1,9 +1,9 @@
-/* $Id: text.c 4448 2009-11-29 06:13:22Z astyanax $ */ 
+/* $Id: text.c 4462 2009-12-12 22:21:20Z astyanax $ */ 
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
- *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007   *
- *   Free Software Foundation, Inc.                                       *
+ *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007,  *
+ *   2008, 2009 Free Software Foundation, Inc.                            *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 3, or (at your option)  *
@@ -66,9 +66,7 @@ void do_mark(void)
 /* Delete the character under the cursor. */
 void do_delete(void)
 {
-    bool do_refresh = FALSE;
-	/* Do we have to call edit_refresh(), or can we get away with
-	 * just update_line()? */
+    size_t orig_lenpt = 0;
 
 #ifndef NANO_TINY
     update_undo(DEL);
@@ -86,6 +84,9 @@ void do_delete(void)
 
 	assert(openfile->current_x < strlen(openfile->current->data));
 
+	if (ISSET(SOFTWRAP))
+	    orig_lenpt = strlenpt(openfile->current->data);
+
 	/* Let's get dangerous. */
 	charmove(&openfile->current->data[openfile->current_x],
 		&openfile->current->data[openfile->current_x +
@@ -108,7 +109,7 @@ void do_delete(void)
 	/* If we're deleting at the end of a line, we need to call
 	 * edit_refresh(). */
 	if (openfile->current->data[openfile->current_x] == '\0')
-	    do_refresh = TRUE;
+	    edit_refresh_needed = TRUE;
 
 	openfile->current->data = charealloc(openfile->current->data,
 		openfile->current_x + strlen(foo->data) + 1);
@@ -138,11 +139,13 @@ void do_delete(void)
     } else
 	return;
 
+    if (ISSET(SOFTWRAP) && edit_refresh_needed == FALSE)
+	if (strlenpt(openfile->current->data) / COLS != orig_lenpt / COLS)
+	    edit_refresh_needed  = TRUE;
+
     set_modified();
 
-    if (do_refresh)
-	edit_refresh_needed = TRUE;
-    else
+    if (edit_refresh_needed  == FALSE)
 	update_line(openfile->current, openfile->current_x);
 }
 
@@ -481,6 +484,7 @@ void do_undo(void)
 	if (u->xflags == UNDO_DEL_BACKSPACE)
 	    openfile->current_x += strlen(u->strdata);
 	break;
+#ifndef DISABLE_WRAPPING
     case SPLIT:
 	undidmsg = _("line wrap");
 	f->data = (char *) nrealloc(f->data, strlen(f->data) + strlen(u->strdata) + 1);
@@ -494,6 +498,7 @@ void do_undo(void)
 	}
 	renumber(f);
 	break;
+#endif /* DISABLE_WRAPPING */
     case UNSPLIT:
 	undidmsg = _("line join");
 	t = make_new_node(f);
@@ -618,6 +623,7 @@ void do_redo(void)
 	do_gotolinecolumn(u->lineno, u->begin+1, FALSE, FALSE, FALSE, FALSE);
 	do_enter(TRUE);
 	break;
+#ifndef DISABLE_WRAPPING
     case SPLIT:
 	undidmsg = _("line wrap");
 	if (u->xflags & UNDO_SPLIT_MADENEW)
@@ -625,6 +631,7 @@ void do_redo(void)
         do_wrap(f, TRUE);
 	renumber(f);
 	break;
+#endif /* DISABLE_WRAPPING */
     case UNSPLIT:
 	undidmsg = _("line join");
 	len = strlen(f->data) + strlen(u->strdata + 1);
@@ -812,7 +819,7 @@ bool execute_command(const char *command)
     if (f == NULL)
 	nperror("fdopen");
 
-    read_file(f, 0, "stdin", TRUE);
+    read_file(f, 0, "stdin", TRUE, FALSE);
 
     if (wait(NULL) == -1)
 	nperror("wait");
@@ -900,6 +907,7 @@ void add_undo(undo_type current_action)
 	    u->strdata = data;
 	}
 	break;
+#ifndef DISABLE_WRAPPING
     case SPLIT:
 	wrap_loc = break_line(openfile->current->data, fill
 #ifndef DISABLE_HELP
@@ -913,6 +921,7 @@ void add_undo(undo_type current_action)
 	    u->strdata2 = mallocstrcpy(NULL, fs->current->next->data);
 	u->begin = wrap_loc;
 	break;
+#endif /* DISABLE_WRAPPING */
     case INSERT:
     case REPLACE:
 	data = mallocstrcpy(NULL, fs->current->data);
@@ -1058,11 +1067,13 @@ void update_undo(undo_type action)
     case INSERT:
 	u->mark_begin_lineno = openfile->current->lineno;
 	break;
+#ifndef DISABLE_WRAPPING
     case SPLIT:
 	/* This will only be called if we made a completely new line,
 	   and as such we should note that so we can destroy it later */
 	u->xflags = UNDO_SPLIT_MADENEW;
 	break;
+#endif /* DISABLE_WRAPPING */
     case UNSPLIT:
 	/* These cases are handled by the earlier check for a new line and action */
     case ENTER:
